@@ -14,10 +14,11 @@ import psycopg2
 from os.path import join, exists
 
 lib_postgresql = '/usr/lib/postgresql/'
+host = 'localhost'
 
 def get_unused_port():
     sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
-    sock.bind(('localhost', 0))
+    sock.bind((host, 0))
     port = sock.getsockname()[1]
     sock.close()
 
@@ -49,12 +50,13 @@ def run_initdb(bin_dir, base_dir):
 def run_server(bin_dir, base_dir, port):
     print('starting server')
     postgres = join(bin_dir, 'bin', 'postgres')
+    assert os.path.exists(postgres)
 
     args = [postgres,
             '-p', str(port),
             '-D', os.path.join(base_dir, 'data'),
             '-k', os.path.join(base_dir, 'tmp'),
-            '-h', '127.0.0.1',
+            '-h', host,
             '-F',
             '-c', 'logging_collector=off']
     return subprocess.Popen(args, stderr=subprocess.PIPE)
@@ -73,7 +75,7 @@ def stop_server(server):
         time.sleep(0.1)
 
 def configure_database(port):
-    conn_params = {'user': 'postgres', 'host': 'localhost', 'port': port}
+    conn_params = {'user': 'postgres', 'host': host, 'port': port}
     for _ in range(50):
         try:
             conn = psycopg2.connect(dbname='template1', **conn_params)
@@ -81,6 +83,7 @@ def configure_database(port):
             allowed = [
                 'the database system is starting up',
                 'could not connect to server: Connection refused',
+                'failed: Connection refused',
             ]
             if not any(msg in e.args[0] for msg in allowed):
                 raise
